---
permalink: /
---

# KMUHelper

Willkommen in der KMUHelper-Dokumentation!

Hier finden Sie alles, was Sie über den KMUHelper wissen müssen!

## Inhalt

-   [Geschichte](history.md)
-   [Funktionen](functions.md)
-   [Installation](installation.md)
-   [Benutzerhandbuch](manual.md)

### Kontakt

Wenn Sie mich kontaktieren möchten, finden Sie [hier](https://rafaelurben.github.io/diverses/rafaelurben/#kontakt) diverse Möglichkeiten dazu.
